<!DOCTYPE html>
  <html lang="en">
    <head>
      <title>${title}</title>
      <meta charset="utf-8" />
      <style>
        html,body {margin:0;padding:0}
        hr {border:1px dashed #000}
        p {margin:0}
        table {table-layout:fixed}
        table td {overflow:hidden;white-space: nowrap}
        .pagina {width:${width}px;font-family:Helvetica, Arial, "Lucida Grande", sans-serif;font-size:${font_size_value}px;margin:40px auto;}
        .recibo-sacado {margin-bottom:50px}
        .demonstrativo {height:190px}
        .demonstrativo-content,.instrucoes-content {padding:3px}
        .autenticacao-mecanica {height:80px}
        .recibo-caixa {margin-top:30px}
        .cabecalho td {border-bottom:4px solid #000;vertical-align:bottom;padding:0}
        .cabecalho td.banco-logo {width:170px}
        .cabecalho td.banco-logo img {float:left;margin:0;padding:0}
        .cabecalho td.banco-codigo {width:70px;font-size:22px;font-weight:700;text-align:center}
        .cabecalho td.bol-linha-digitavel {border-right:none;text-align:right;font-size:16px;font-weight:700}
        .cabecalho .linhas-v {border-left:3px solid #000;border-right:3px solid #000}
        .corpo td {border-bottom:1px solid #000;border-right:1px solid #000;vertical-align:top;height:${height_line}px;padding:0 2px}
        .corpo td.linha-vazia {border-bottom:none}
        .recibo-sacado .corpo tr td:last-child {border-right:none;text-align:left}
        .recibo-caixa .corpo tr td:last-child {border-right:none;text-align:right;width:140px}
        .rodape td {border:none;vertical-align:top;padding-left:2px}
        .rodape td.bol-codigo-barras {padding:8px 6px}
        .rotulo {text-align:left;font-size:${font_size_title}px;margin-bottom:2px}
        .autenticacao-mecanica .rotulo {text-align:right}
        tr.linha-grossa td, td.linha-grossa {border-bottom:3px solid #000}
        .recibo-sacado .corpo .col-cedente-agencia,.recibo-sacado .corpo .col-cedente-documento {width:130px}
        .recibo-sacado .corpo .col-vencimento {width:100px}
        .recibo-caixa .corpo .col-data-documento {width:120px}
        .recibo-caixa .corpo .col-numero-documento {width:140px}
        .recibo-caixa .rodape .col-sacado {width:40px}
        .recibo-caixa .rodape .col-codigo-baixa {width:210px}
        .cabecalho,.corpo,.rodape {width:100%;border-collapse:collapse}
        .recibo-caixa .corpo .col-especie-documento,.recibo-caixa .corpo .col-aceite {width:70px}
        .bol-codigo-barras {height:40px}
        #barcode {height: 60px}
        #barcode span {margin: 0;padding-bottom: 34px;height: 16px}
        .n {border-left: 1px solid}
        .w {border-left: 3px solid}
        .n, .w {border-color: #000}
        .s {border-color: #fff}
        /* @media print{ .pagina {page-break-after:always} } */
      </style>
    </head>
    <body>
      <div class="pagina">
